% Copyright (c) 2018, Voilà Contributors
% Copyright (c) 2018, QuantStack
%
% Distributed under the terms of the BSD 3-Clause License.
%
% The full license is in the file LICENSE, distributed with this software.

```{image} voila-logo.svg
:alt: voila
```

_From notebooks to static web applications and dashboards._

Voici allows you to convert a Jupyter Notebook into an
interactive dashboard that allows you to share your work with others. It
is secure and customizable, giving you control over what your readers
experience.

Voici is the combination of [Voilà](https://github.com/voila-dashboards/voila) and [JupyterLite](https://github.com/jupyterlite/jupyterlite).

# Try it online

You can try Voici using the following link:

[![JupyterLite](https://jupyterlite.rtfd.io/en/latest/_static/badge-launch.svg)](https://voici.readthedocs.io/en/latest/_static/lite/voici/tree/index.html)

# Table of contents

For more information about Voici, see the sections below.

```{toctree}
:maxdepth: 2

install
deploy
configuration
changelog
contributing
```
